<?php
/**
 * @version    1.0.0
 * @package    Com_Stopbadbots
 * @author     Bill Minozzi <sergiominozzi@gmail.com>
 * @copyright  2020  Minozzi
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;
jimport('joomla.application.component.view');
use \Joomla\CMS\Language\Text;
/**
 * View class for a list of Stopbadbots.
 *
 * @since  1.0
 */
class StopbadbotsViewBots extends \Joomla\CMS\MVC\View\HtmlView
{
	protected $items;
	protected $pagination;
	protected $state;
	/**
	 * Display the view
	 *
	 * @param   string  $tpl  Template name
	 *
	 * @return void
	 *
	 * @throws Exception
	 */
	public function display($tpl = null)
	{
		$this->state = $this->get('State');
		$this->items = $this->get('Items');
		$this->pagination = $this->get('Pagination');
        $this->filterForm = $this->get('FilterForm');
        $this->activeFilters = $this->get('ActiveFilters');
		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new Exception(implode("\n", $errors));
		}
		StopbadbotsHelper::addSubmenu('bots');
		$this->addToolbar();
		$this->sidebar = JHtmlSidebar::render();
		parent::display($tpl);
	}
	/**
	 * Add the page title and toolbar.
	 *
	 * @return void
	 *
	 * @since    1.6
	 */
	protected function addToolbar()
	{
		$state = $this->get('State');
		$canDo = StopbadbotsHelper::getActions();
		JToolBarHelper::title(Text::_('COM_STOPBADBOTS_TITLE_BOTS'), 'bots.png');
		// Check if the form exists before showing the add/edit buttons
		$formPath = JPATH_COMPONENT_ADMINISTRATOR . '/views/bot';
		if (file_exists($formPath))
		{
			if ($canDo->get('core.create'))
			{
				JToolBarHelper::addNew('bot.add', 'JTOOLBAR_NEW');
				// JToolBarHelper::addNew(string $task, string $alt, boolean  $check); // Will call the task/function $task in your controller
				if (isset($this->items[0]))
				{
				//	JToolbarHelper::custom('bots.duplicate', 'copy.png', 'copy_f2.png', 'JTOOLBAR_DUPLICATE', true);
				}
			}
			if ($canDo->get('core.edit') && isset($this->items[0]))
			{
				JToolBarHelper::editList('bot.edit', 'JTOOLBAR_EDIT');
			}
		}
		if ($canDo->get('core.edit.state'))
		{
			if (isset($this->items[0]->state))
			{
				JToolBarHelper::divider();
				JToolBarHelper::custom('bots.publish', 'publish.png', 'publish_f2.png', 'JTOOLBAR_PUBLISH', true);
				JToolBarHelper::custom('bots.unpublish', 'unpublish.png', 'unpublish_f2.png', 'JTOOLBAR_UNPUBLISH', true);
			}
			elseif (isset($this->items[0]))
			{
				// If this component does not use state then show a direct delete button as we can not trash
				//JToolBarHelper::deleteList('', 'bots.delete', 'JTOOLBAR_DELETE');
			}
			if (isset($this->items[0]->state))
			{
				JToolBarHelper::divider();
				JToolBarHelper::archiveList('bots.archive', 'JTOOLBAR_ARCHIVE');
			}
			if (isset($this->items[0]->checked_out))
			{
				JToolBarHelper::custom('bots.checkin', 'checkin.png', 'checkin_f2.png', 'JTOOLBAR_CHECKIN', true);
			}
		}
		// Show trash and delete for components that uses the state field
		if (isset($this->items[0]->state))
		{
			if ($state->get('filter.state') == -2 && $canDo->get('core.delete'))
			{
				JToolBarHelper::deleteList('', 'bots.delete', 'JTOOLBAR_EMPTY_TRASH');
				JToolBarHelper::divider();
			}
			elseif ($canDo->get('core.edit.state'))
			{
				JToolBarHelper::trash('bots.trash', 'JTOOLBAR_TRASH');
				JToolBarHelper::divider();
			}
		}
		if ($canDo->get('core.admin'))
		{
			JToolBarHelper::preferences('com_stopbadbots');
		}
		// Set sidebar action - New in 3.0
		JHtmlSidebar::setAction('index.php?option=com_stopbadbots&view=bots');
	}
	/**
	 * Method to order fields 
	 *
	 * @return void 
	 */
	protected function getSortFields()
	{
		return array(
			'a.id' => JText::_('JGRID_HEADING_ID'),
			'a.botnickname' => JText::_('COM_STOPBADBOTS_BOTS_BOTNICKNAME'),
			'a.botname' => JText::_('COM_STOPBADBOTS_BOTS_BOTNAME'),
			'a.botstate' => JText::_('COM_STOPBADBOTS_BOTS_BOTSTATE'),
			'a.botblocked' => JText::_('COM_STOPBADBOTS_BOTS_BOTBLOCKED'),
		);
	}
    /**
     * Check if state is set
     *
     * @param   mixed  $state  State
     *
     * @return bool
     */
    public function getState($state)
    {
        return isset($this->state->{$state}) ? $this->state->{$state} : false;
    }
}
